@@ -11,10 +11,7 @@
 #' @export
 #'
 #' @examples
-#' ## Using default (all metrics)
-#' # metrics_heatmap(example_data_5_subject)
-#'
-#' # Using pre-calculated sd metrics only
+#' # Using pre-calculated sd metrics only rather than default (all metrics)
 #' mecs = sd_measures(example_data_5_subject)
 #' metrics_heatmap(metrics = mecs)
 metrics_heatmap <- function(data = NULL, metrics = NULL, metric_cluster = 6, clustering_method = "complete",
@@ -26,6 +23,7 @@ metrics_heatmap <- function(data = NULL, metrics = NULL, metric_cluster = 6, clu
     if(is.null(data)){
       stop("Either CGM data or precalculated metrics must be provided")
     }else{
+      data = check_data_columns(data, time_check=TRUE)
       # No metrics are provided, calculate all by default
       mecs = all_metrics(data)
     }
